==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/options_panel/msa/GTTestsOptionPanelMSA.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef U2_GTTESTS_OPTION_PANEL_MSA_H
#define U2_GTTESTS_OPTION_PANEL_MSA_H

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_options_panel_MSA {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_options_panel_MSA"

GUI_TEST_CLASS_DECLARATION(general_test_0001)
GUI_TEST_CLASS_DECLARATION(general_test_0001_1)
GUI_TEST_CLASS_DECLARATION(general_test_0002)
GUI_TEST_CLASS_DECLARATION(general_test_0003)
GUI_TEST_CLASS_DECLARATION(general_test_0004)
GUI_TEST_CLASS_DECLARATION(general_test_0005)

GUI_TEST_CLASS_DECLARATION(highlighting_test_0001)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_2)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_3)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_4)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0002)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0002_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0003)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_2)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_3)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_4)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_5)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_6)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_7)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_8)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_9)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0005)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0005_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0006)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0007)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0007_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0008)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0008_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0009)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0009_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0010)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0010_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0011)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0012)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0013)

GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0001)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0002)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0003)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0004)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0005)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0005_1)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0006)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007_1)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007_2)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007_3)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0008)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0009)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0010)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0011)

GUI_TEST_CLASS_DECLARATION(tree_settings_test_0001)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0002)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0003)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0004)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0005)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0006)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0007)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0008)

GUI_TEST_CLASS_DECLARATION(export_consensus_test_0001)
GUI_TEST_CLASS_DECLARATION(export_consensus_test_0002)
GUI_TEST_CLASS_DECLARATION(export_consensus_test_0003)
GUI_TEST_CLASS_DECLARATION(export_consensus_test_0004)

GUI_TEST_CLASS_DECLARATION(statistics_test_0001)
GUI_TEST_CLASS_DECLARATION(statistics_test_0002)
GUI_TEST_CLASS_DECLARATION(statistics_test_0003)

GUI_TEST_CLASS_DECLARATION(save_parameters_test_0001)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0002)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0003)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0003_1)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0004)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0004_1)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0005)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0006)

}  // namespace GUITest_common_scenarios_options_panel_MSA

}  // namespace U2
#endif  // GTTESTSOPTIONPANELMSA_H

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/GUITestBase/src/tests/common_scenarios/options_panel/msa/GTTestsOptionPanelMSA.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_options_panel_MSA {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_options_panel_MSA"

GUI_TEST_CLASS_DECLARATION(general_test_0001)
GUI_TEST_CLASS_DECLARATION(general_test_0001_1)
GUI_TEST_CLASS_DECLARATION(general_test_0002)
GUI_TEST_CLASS_DECLARATION(general_test_0003)
GUI_TEST_CLASS_DECLARATION(general_test_0004)
GUI_TEST_CLASS_DECLARATION(general_test_0005)

GUI_TEST_CLASS_DECLARATION(highlighting_test_0001)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_2)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_3)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0001_4)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0002)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0002_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0003)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_2)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_3)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_4)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_5)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_6)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_7)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_8)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0004_9)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0005)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0005_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0006)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0007)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0007_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0008)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0008_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0009)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0009_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0010)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0010_1)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0011)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0012)
GUI_TEST_CLASS_DECLARATION(highlighting_test_0013)

GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0001)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0002)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0003)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0004)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0005)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0005_1)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0006)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007_1)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007_2)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0007_3)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0008)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0009)
GUI_TEST_CLASS_DECLARATION(pairwise_alignment_test_0010)

GUI_TEST_CLASS_DECLARATION(tree_settings_test_0001)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0002)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0003)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0004)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0005)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0006)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0007)
GUI_TEST_CLASS_DECLARATION(tree_settings_test_0008)

GUI_TEST_CLASS_DECLARATION(export_consensus_test_0001)
GUI_TEST_CLASS_DECLARATION(export_consensus_test_0002)
GUI_TEST_CLASS_DECLARATION(export_consensus_test_0003)
GUI_TEST_CLASS_DECLARATION(export_consensus_test_0004)

GUI_TEST_CLASS_DECLARATION(statistics_test_0001)
GUI_TEST_CLASS_DECLARATION(statistics_test_0002)
GUI_TEST_CLASS_DECLARATION(statistics_test_0003)

GUI_TEST_CLASS_DECLARATION(save_parameters_test_0001)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0002)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0003)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0003_1)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0004)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0004_1)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0005)
GUI_TEST_CLASS_DECLARATION(save_parameters_test_0006)

}  // namespace GUITest_common_scenarios_options_panel_MSA

}  // namespace U2
